<?xml version="1.0"?>
<xsl:stylesheet version = "1.0" xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" xmlns:docs="http://tempuri.org/docs" xmlns:ix="urn:RevisableObjectImportTemplate.xsd" exclude-result-prefixes="docs">
	<docs:transformationMetaData>
		<docs:name>HTML Transformation</docs:name>
		<docs:description>HTML file containing all attributes except TableAttributes. No incoming or outgoing traces. Must use Convert RTF to plain text</docs:description>
		<docs:extension>.htm</docs:extension>
    <docs:onlyAsPlaintext>true</docs:onlyAsPlaintext>
	</docs:transformationMetaData>
	<xsl:output method="html" indent="yes"/>
	<xsl:template match="ix:DocumentObjects">
		<html>
			<head>
				<style type="text/css">
					td {font: 12px verdana}
					td.bold {font: bold 12px verdana}
					table.coll {border-collapse: collapse }
				</style>
			</head>
			<body>
				<xsl:apply-templates/>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="ix:DocumentObject">
		<table class="coll" border="1" cellpadding="10"  width ="600">

				<tr>
					<td class="bold" width="25%">ID:</td>
					<td width="75%">
						<xsl:value-of select="normalize-space(@ProjectName)"/>
						-
						<xsl:value-of select="normalize-space(@ID)"/>
					</td>
				</tr>
				<tr>
					<td class="bold">Title:</td>
					<td>
						<xsl:value-of select="normalize-space(@Title)"/>
						<xsl:text/>
					</td>
				</tr>
				<xsl:for-each select="ix:Attributes/ix:Attribute">
					<xsl:choose>
						<xsl:when test="@AttributeType != 'TableAttribute'">
							<tr>
								<td class="bold" >
									<xsl:value-of select="@AttributeName"/>
									<xsl:text>:</xsl:text>
								</td>
								<td>
                  <xsl:variable name="myString" select="."/>
                  <xsl:variable name="firstReplaceString">
                    <xsl:call-template name="replaceCharsInString">
                      <xsl:with-param name="stringIn" select="string($myString)"/>
                      <xsl:with-param name="charsIn" select="'¢¢'"/>
                      <xsl:with-param name="charsOut" select="'\n'"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:variable name="secondReplaceString">
                    <xsl:call-template name="replaceCharsInString">
                      <xsl:with-param name="stringIn" select="string($firstReplaceString)"/>
                      <xsl:with-param name="charsIn" select="'££'"/>
                      <xsl:with-param name="charsOut" select="'\r'"/>
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:variable name="theFinalString" select="string($secondReplaceString)"/>

                  <xsl:copy-of select="$theFinalString"/>
                  
								</td>
							</tr>
						</xsl:when>
						<xsl:otherwise>
								<tr>
									<td class="bold">
										<xsl:value-of select="@AttributeName"/>
										<xsl:text>:</xsl:text>
									</td>
									<td>
										<table class="coll" border="1" width="100%">
											<tr>
												<xsl:for-each select="ix:Table/ix:Columns/ix:ColumnName">
													<td class="bold">
														<xsl:value-of select="."/>
													</td>
												</xsl:for-each>
											</tr>
											<xsl:for-each select="ix:Table/ix:Rows/ix:Row">
												<tr>
													<xsl:for-each select="ix:Cells/ix:Cell">
														<td>
                              <xsl:variable name="myString" select="."/>
                              <xsl:variable name="firstReplaceString">
                                <xsl:call-template name="replaceCharsInString">
                                  <xsl:with-param name="stringIn" select="string($myString)"/>
                                  <xsl:with-param name="charsIn" select="'¢¢'"/>
                                  <xsl:with-param name="charsOut" select="'\n'"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <xsl:variable name="secondReplaceString">
                                <xsl:call-template name="replaceCharsInString">
                                  <xsl:with-param name="stringIn" select="string($firstReplaceString)"/>
                                  <xsl:with-param name="charsIn" select="'££'"/>
                                  <xsl:with-param name="charsOut" select="'\r'"/>
                                </xsl:call-template>
                              </xsl:variable>
                              <xsl:variable name="theFinalString" select="string($secondReplaceString)"/>

                              <xsl:copy-of select="$theFinalString"/>
													</td>
												</xsl:for-each>
												</tr>
											</xsl:for-each>
										</table>

									</td>
								</tr>
								

						</xsl:otherwise>


					</xsl:choose>


				</xsl:for-each>
			</table>
		<p> </p>
		<p> </p>
	</xsl:template>
  <xsl:template name="replaceCharsInString">
    <xsl:param name="stringIn"/>
    <xsl:param name="charsIn"/>
    <xsl:param name="charsOut"/>
    <xsl:choose>
      <xsl:when test="contains($stringIn,$charsIn)">
        <xsl:value-of select="concat(substring-before($stringIn,$charsIn),$charsOut)"/>
        <xsl:call-template name="replaceCharsInString">
          <xsl:with-param name="stringIn" select="substring-after($stringIn,$charsIn)"/>
          <xsl:with-param name="charsIn" select="$charsIn"/>
          <xsl:with-param name="charsOut" select="$charsOut"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$stringIn"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>